<?php
/**
 * Add Note capability to dokuwiki
 * <note>This is note</note>
 * <note classic>This is note</note>
 * <note important>This is an important note</note>
 * <note warning>This is a big warning</note>
 * <note tip>This is a tip</note>
 *
 * HIGHLY derived from the work of :
 * Stephane Chamberland <stephane.chamberland@ec.gc.ca> (Side Notes PlugIn)
 * Carl-Christian Salvesen <calle@ioslo.net> (Graphviz plugin)
 * Modified by Eric Hameleers to use <div> instead of <table> and to
 *   contain the images and stylesheet inside the plugin.
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Olivier Cortes <olivier.cortes@ryxeo.com>
 */
 
if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../').'/');
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'syntax.php');

/* for debugging only, install PEAR PHP_Compat and activate the following line :
require_once '/usr/share/php/PHP/Compat/Function/file_put_contents.php';
*/


/**
 * All DokuWiki plugins to extend the parser/rendering mechanism
 * need to inherit from this class
 */
class syntax_plugin_note extends DokuWiki_Syntax_Plugin {
 
    /**
     * return some info
     */
    function getInfo(){
        return array(
            'author' => 'Olivier Cortes / Eric Hameleers',
            'email'  => 'alien@slackware.com',
            'date'   => '2006-03-22',
            'name'   => 'Note Plugin',
            'desc'   => 'Add Note/Important/Tip/Warning Capability (DIV+CSS box)',
            'url'    => 'http://wiki.splitbrain.org/plugin:note',
        );
    }
 
    /**
     * Constructor - adds allowed modes
     */
    function syntax_plugin_note(){
        global $PARSER_MODES;
        $this->allowedModes = array_merge(
            $PARSER_MODES['container'],
            $PARSER_MODES['paragraphs'],
            $PARSER_MODES['formatting'],
            $PARSER_MODES['substition']
        );
    }
 
    /**
     * What kind of syntax are we?
     */
    function getType(){
        return 'container';
    }
 
   /**
    * Paragraph Type
    *
    * Defines how this syntax is handled regarding paragraphs. This is important
    * for correct XHTML nesting. Should return one of the following:
    *
    * 'normal' - The plugin can be used inside paragraphs
    * 'block'  - Open paragraphs need to be closed before plugin output
    * 'stack'  - Special case. Plugin wraps other paragraphs.
    *
    * @see Doku_Handler_Block
    */
    function getPType(){
        return 'normal';
    }
 
    /* for debugging only, uncomment the following function and the require block at the
     * beginning of this file.
     *
     * call this as :
     *      $this->debug("print the debug message:" . $var_to_debug);
     *
     *
    function debug($msg) {
      file_put_contents("/tmp/debug.doku.note.log", $msg . "\n", FILE_APPEND);
    }
     *
     * /
  
    /**
     * Where to sort in?
     */
    function getSort(){
        return 111;
    }
 
    /**
     * Connect pattern to lexer
     */
    function connectTo($mode) {
        //$this->debug("mode = " . $mode);
        $this->Lexer->addEntryPattern('<note(?=.*\x3C/note\x3E)',$mode,'plugin_note');
    }
    function postConnect() {
        $this->Lexer->addExitPattern('</note>','plugin_note');
    }

    /**
     * Handle the match
     */
    function handle($match, $state, $pos, &$handler){

        //$this->debug(">>> state = " . $state . ", match = " . $match );

        if ( $state == DOKU_LEXER_UNMATCHED) {
                $matches = preg_split('/>/u',$match,2);
                //$this->debug("UNMATCHED : matches[0] = " . $matches[0] . ", matches[1] = " . $matches[1]);
                 $matches[0] = trim($matches[0]);
                if ( $matches[0] == '' ) {
                  $matches[0] = NULL;
                }
                return array($state, $matches[0], $matches[1]);
        }
        return array($state);
    }
 
    /**
     * Create output
     */
    function render($mode, &$renderer, $data) {
        if($mode == 'xhtml'){

          //$this->debug("APPEL renderer, data[0] = " . $data[0] . ", data[1] = " . $data[1] . ", data[2] = " . $data[2]);
          
            if ($data[0] == DOKU_LEXER_UNMATCHED){
                if ( $data[1] == 'important' || $data[1] == 'important' ) {
                    $css_class = "noteimportant";
                }
                else if ($data[1] == 'warning' || $data[1] == 'bloquante' || $data[1] == 'critique' ) {
                    $css_class = "notewarning";
                }
                else if ($data[1] == 'tip' || $data[1] == 'tuyau' || $data[1] == 'idee') {
                    $css_class = "notetip";
                }
                else if ( $data[1] == 'classic' || $data[1] == 'classique' || $data[1] == '' ){
                    $css_class = "noteclassic";
                }
                else {
                    // Fallback - take a dokuwiki standard style
                    $css_class = "info";
                }
                //$this->debug("START, data[0] = " . $data[0] . ", data[1] = " . $data[1] . ", data[2] = " . $data[2]);
                $renderer->doc .= '</p><div class="' . $css_class . '"><p>';
                $renderer->doc .= $data[2];
            } else if ($data[0] == DOKU_LEXER_EXIT){
                $renderer->doc .= '</p></div><p>';
            }
            return true;
        }
        return false;
    }
 
}
 
//Setup VIM: ex: et ts=4 enc=utf-8 :
?>
